==> libggi-2.1.0.src.tar.bz2: libggi-2.1.0/default/text_16/visual.c <==
/* $Id: visual.c,v 1.3 2004/02/23 14:24:51 pekberg Exp $
******************************************************************************

   Graphics library for GGI.

   Copyright (C) 1995 Andreas Beck	[becka@ggi-project.org]
   Copyright (C) 1997 Jason McMullan	[jmcc@ggi-project.org]
   Copyright (C) 2000 Marcus Sundberg	[marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include "t16lib.h"


static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
		   const char *args, void *argptr, uint32 *dlret)
{
	/* Color handling
	 */
	vis->opcolor->mapcolor		= GGI_t16_mapcolor;
	vis->opcolor->unmappixel	= GGI_t16_unmappixel;

	/* Frame handling
	 */

	vis->opdraw->setreadframe	= _ggi_default_setreadframe;
	vis->opdraw->setwriteframe	= _ggi_default_setwriteframe;
	
	/* Generic drawing is minimal
	 */
	if (vis->needidleaccel) {
		vis->opdraw->drawpixel_nc	= GGI_t16_drawpixel_nca;
		vis->opdraw->drawpixel		= GGI_t16_drawpixela;
		vis->opdraw->putpixel_nc	= GGI_t16_putpixel_nca;
		vis->opdraw->putpixel		= GGI_t16_putpixela;
		vis->opdraw->getpixel		= GGI_t16_getpixela;
	} else {
		vis->opdraw->drawpixel_nc	= GGI_t16_drawpixel_nc;
		vis->opdraw->drawpixel		= GGI_t16_drawpixel;
		vis->opdraw->putpixel_nc	= GGI_t16_putpixel_nc;
		vis->opdraw->putpixel		= GGI_t16_putpixel;
		vis->opdraw->getpixel		= GGI_t16_getpixel;
	}

	vis->opdraw->putc		= GGI_t16_putc;
	vis->opdraw->getcharsize	= GGI_t16_getcharsize;
	
	*dlret = GGI_DL_OPDRAW | GGI_DL_OPCOLOR;
	return 0;
}


EXPORTFUNC
int GGIdl_text_16(int func, void **funcptr);

int GGIdl_text_16(int func, void **funcptr)
{
	switch (func) {
	case GGIFUNC_open:
		*funcptr = GGIopen;
		return 0;
	case GGIFUNC_exit:
	case GGIFUNC_close:
		*funcptr = NULL;
		return 0;
	default:
		*funcptr = NULL;
	}

	return GGI_ENOTFOUND;
}

#include <ggi/internal/ggidlinit.h>

==> libggi2-2.2.2-3-src.tar.bz2: libggi-2.2.2/default/text_16/visual.c <==
/* $Id: visual.c,v 1.5 2005/07/30 11:40:03 cegger Exp $
******************************************************************************

   Graphics library for GGI.

   Copyright (C) 1995 Andreas Beck	[becka@ggi-project.org]
   Copyright (C) 1997 Jason McMullan	[jmcc@ggi-project.org]
   Copyright (C) 2000 Marcus Sundberg	[marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include "t16lib.h"


static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
		   const char *args, void *argptr, uint32_t *dlret)
{
	/* Color handling
	 */
	vis->opcolor->mapcolor		= GGI_t16_mapcolor;
	vis->opcolor->unmappixel	= GGI_t16_unmappixel;

	/* Frame handling
	 */

	vis->opdraw->setreadframe	= _ggi_default_setreadframe;
	vis->opdraw->setwriteframe	= _ggi_default_setwriteframe;
	
	/* Generic drawing is minimal
	 */
	if (vis->needidleaccel) {
		vis->opdraw->drawpixel_nc	= GGI_t16_drawpixel_nca;
		vis->opdraw->drawpixel		= GGI_t16_drawpixela;
		vis->opdraw->putpixel_nc	= GGI_t16_putpixel_nca;
		vis->opdraw->putpixel		= GGI_t16_putpixela;
		vis->opdraw->getpixel		= GGI_t16_getpixela;
	} else {
		vis->opdraw->drawpixel_nc	= GGI_t16_drawpixel_nc;
		vis->opdraw->drawpixel		= GGI_t16_drawpixel;
		vis->opdraw->putpixel_nc	= GGI_t16_putpixel_nc;
		vis->opdraw->putpixel		= GGI_t16_putpixel;
		vis->opdraw->getpixel		= GGI_t16_getpixel;
	}

	vis->opdraw->putc		= GGI_t16_putc;
	vis->opdraw->getcharsize	= GGI_t16_getcharsize;
	
	*dlret = GGI_DL_OPDRAW | GGI_DL_OPCOLOR;
	return 0;
}


EXPORTFUNC
int GGIdl_text_16(int func, void **funcptr);

int GGIdl_text_16(int func, void **funcptr)
{
	switch (func) {
	case GGIFUNC_open:
		*funcptr = (void *)GGIopen;
		return 0;
	case GGIFUNC_exit:
	case GGIFUNC_close:
		*funcptr = NULL;
		return 0;
	default:
		*funcptr = NULL;
	}

	return GGI_ENOTFOUND;
}

#include <ggi/internal/ggidlinit.h>
